@@ -276,6 +276,9 @@ namespace Beagle.Daemon
 
 			Thread crawl_thread, index_thread, monitor_thread = null;
 
+			Stopwatch watch = new Stopwatch ();
+			watch.Start ();
+
 			// Start the thread that does the crawling
 			crawl_thread = ExceptionHandlingThread.Start (new ThreadStart (CrawlWorker));
 
@@ -293,6 +296,9 @@ namespace Beagle.Daemon
 			if (monitor_thread != null)
 				monitor_thread.Join ();
 
+			watch.Stop ();
+			Logger.Log.Debug ("Elapsed time {0}.", watch);
+
 			if (restart) {
 				Logger.Log.Debug ("Restarting helper");
 				Process p = new Process ();
@@ -355,7 +361,7 @@ namespace Beagle.Daemon
 					
 			// Tag the item for easy identification (for say, removal)
 			if (arg_tag != null)
-				indexable.AddProperty (Property.NewKeyword("Tag", arg_tag));
+				indexable.AddProperty (Property.NewUnsearched("Tag", arg_tag));
 
 			if (arg_source == null) {
 				DirectoryInfo dir = new DirectoryInfo (StringFu.SanitizePath (arg_output));
@@ -474,7 +480,7 @@ namespace Beagle.Daemon
 		{
 			int vmrss_original = SystemInformation.VmRss;
 
-			const double threshold = 5.0;
+			const double threshold = 6.0;
 			int last_vmrss = 0;
 
 			while (! shutdown && (crawling || indexing)) {
