@@ -189,6 +189,7 @@ namespace Beagle.Daemon.LifereaQueryable {
 		private bool is_valid_file = true;
 
 		private string feed_source = "";
+		private string publisher = "";
 		private Item current_item;
 		private XmlSerializer serializer;
 		
@@ -243,7 +244,11 @@ namespace Beagle.Daemon.LifereaQueryable {
 						feed_source = reader.ReadString ();
 						reader.ReadEndElement ();
 						break;
-						
+					case "feedTitle":
+						reader.ReadStartElement ("feedTitle");
+						publisher = reader.ReadString ();
+						reader.ReadEndElement ();
+						break;	
 					// ignore other elements
 					default:
 						reader.ReadOuterXml ();
@@ -295,7 +300,12 @@ namespace Beagle.Daemon.LifereaQueryable {
 
 		private Indexable current_itemToIndexable ()
 		{
-			Indexable indexable = new Indexable (new Uri (String.Format ("{0};item={1}", feed_source, current_item.Source)));
+			Indexable indexable;
+			try {
+				indexable = new Indexable (new Uri (String.Format ("{0};item={1}", feed_source, current_item.Source)));
+			} catch (System.UriFormatException) {
+				indexable = new Indexable (new Uri (String.Format ("liferea://dummy?{0};item={1}", feed_source, current_item.Source)));
+			}
 			indexable.ParentUri = UriFu.PathToFileUri (feed_file);
 			indexable.MimeType = "text/html";
 			indexable.HitType = "FeedItem";
@@ -320,6 +330,7 @@ namespace Beagle.Daemon.LifereaQueryable {
 			indexable.AddProperty (Property.NewDate ("dc:date", date));
 			indexable.AddProperty (Property.NewKeyword ("dc:identifier", current_item.Source));
 			indexable.AddProperty (Property.NewKeyword ("dc:source", feed_source));
+			indexable.AddProperty (Property.New ("dc:publisher", publisher));
 				
 			StringReader reader = new StringReader (current_item.Description);
 			indexable.SetTextReader (reader);
@@ -335,7 +346,7 @@ namespace Beagle.Daemon.LifereaQueryable {
 		[XmlElement ("description")] public string Description ="";
 		[XmlElement ("source")] public string Source="";
 		[XmlElement ("attributes")] public Attributes Attribs;
-		[XmlElement ("time")] public ulong Timestamp; 
+		[XmlElement ("time")] public long Timestamp;
 	}
 
 	public class Attributes {
